#  _________________________________________________________________________
#
#  PyUtilib: A Python utility library.
#  Copyright (c) 2008 Sandia Corporation.
#  This software is distributed under the BSD License.
#  Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
#  the U.S. Government retains certain rights in this software.
#  _________________________________________________________________________

class StreamIndenter(object):
    """Mock-up of a file-like object that wraps another file-like object
    and indents all data using the specified string before passing it to
    the underlying file.  Since this presents a full file interface,
    StreamIndenter objects may be arbitrarily nested."""
    
    def __init__(self, ostream, indent="        "):
        self.os = ostream
        self.indent = indent
        self.newline = True
    def __getattr__(self, attr):
        if attr == 'newlines':
            return self.os.newlines
        if attr == 'closed':
            return self.os.closed
        if attr == 'encoding':
            return self.os.encoding
        if attr == 'mode':
            return self.os.mode
        if attr == 'name':
            return self.os.name
        if attr == 'softspace':
            return self.os.softspace
        raise AttributeError, "Unsupported attribute %s" % ( attr )
    def close(self):
        return self.os.close()
    def flush(self):
        return self.os.flush()
    def fileno(self):
        return self.os.fileno()
    def isatty(self):
        return self.os.isatty()
    def next(self):
        return self.os.next()
    def seek(self, *args, **kwargs):
        return self.os.seek(*args, **kwargs)
    def tell():
        return self.os.truncate(*args, **kwargs)
    def truncate(self, *args, **kwargs):
        return self.os.truncate(*args, **kwargs)
    def write(self, str):
        if not len(str):
            return
        if self.newline:
            self.os.write(self.indent)
            self.newline = False
        frag = str.rsplit('\n', 1)
        self.os.write(frag[0].replace('\n', '\n'+self.indent))
        if len(frag)>1:
            self.os.write('\n')
            if len(frag[1]):
                self.os.write(self.indent + frag[1])
            else:
                self.newline = True
    def writelines(self, sequence):
        for x in sequence:
            self.write(x)
